#!/bin/bash

FICHFUNCS="/usr/bin/vx-funcs-bash"
[ -f "${FICHFUNCS}" ] && . "${FICHFUNCS}" "null"

echo "=> Script de postrun de centro específico"

# issue: https://soporte.vitalinux.educa.aragon.es/issues/5705
# Eliminamos y Creamos la cuenta de usuario de Estudiante/Alumno los viernes de cada semana:
# Comando date: %w      Día de la semana en número (0..6, 0 es domingo, 5 es viernes)
function crear_estudiante() {
    COM="Estudiante · IES Joaquín Torres de Mequinenza"
    # Comprobamos que exista el grupo estudiante y alumno:
    GPRIMARIO="alumno"
    ! getent group "${GPRIMARIO}" >/dev/null 2>&1 && groupadd "${GPRIMARIO}" && echo "=> Hemos creado el grupo ${GPRIMARIO} ya que no existía ..."
    GPRIMARIO="estudiante"
    ! getent group "${GPRIMARIO}" >/dev/null 2>&1 && groupadd "${GPRIMARIO}" && echo "=> Hemos creado el grupo ${GPRIMARIO} ya que no existía ..."
    useradd -m -d "/home/estudiante" \
        -s "/bin/bash" \
        -g "${GPRIMARIO}" \
        -G "alumno,cdrom,dip,plugdev,sambashare,dialout,nopasswdlogin" \
        -p "$(echo -n "estudiante" | mkpasswd -s -m sha-512)" \
        -c "${COM}" "estudiante"
    echo "$(date) - Se ha creado la cuenta de ${COM}"
}
if ! getent passwd "estudiante" >/dev/null 2>&1 && ! getent passwd "alumno" >/dev/null 2>&1; then
    crear_estudiante
fi
if [[ $(date +'%w') == "5" ]]; then
    # Preparamos la auditoria:
    LOG="vx-usuario-estudiante-volatil.log"
    vx-log_xsession -o "${LOG}"
    # Eliminamos la cuenta de usuario de alumno/estudiante que pudiera haber:
    for USU in "alumno" "estudiante"; do
        getent passwd "${USU}" &&
            {
                userdel -fr "${USU}" &&
                    echo "Se ha eliminado la cuenta de usuario: \"${USU}\""
            } || echo "No existe ninguna cuenta \"${USU}\" que eliminar"
    done
    crear_estudiante
fi
